PyKEEN
======
.. automodule:: pykeen

.. toctree::
   :caption: Getting Started
   :name: quickstart
   :maxdepth: 2

   first_steps

.. toctree::
   :caption: Reference
   :name: reference
   :maxdepth: 2

   reference/pipeline
   reference/models
   reference/datasets
   reference/triples
   reference/training
   reference/stoppers
   reference/losses
   reference/evaluation/index
   reference/sampling
   reference/hpo

.. toctree::
   :caption: Appendix
   :name: appendix
   :maxdepth: 2

   references

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
